

.. image:: https://secure.travis-ci.org/collective/collective.restapi.pam.png?branch=master
 :target: http://travis-ci.org/collective/collective.restapi.pam

.. image:: https://coveralls.io/repos/github/collective/collective.restapi.pam/badge.svg?branch=master
 :target: https://coveralls.io/github/collective/collective.restapi.pam?branch=master

.. image:: https://landscape.io/github/collective/collective.restapi.pam/master/landscape.svg?style=flat
  :target: https://landscape.io/github/collective/collective.restapi.pam/master
  :alt: Code Health

.. image:: https://readthedocs.org/projects/collectiverestapipam/badge/?version=latest
  :target: https://collectiverestapipam.readthedocs.io/en/latest/?badge=latest


======================
collective.restapi.pam
======================

An add-on providing plone.restapi endpoint for translations handled using
`plone.app.multilingual`_ versions 1.x and 2.x


Documentation
-------------

Full documentation for end users can be found in the "docs" folder, and is also available online at https://collectiverestapipam.readthedocs.io



Installation
------------

Install collective.restapi.pam by adding it to your buildout::

    [buildout]

    ...

    eggs =
        collective.restapi.pam


and then running ``bin/buildout``


Contribute
----------

- Issue Tracker: https://github.com/collective/collective.restapi.pam/issues
- Source Code: https://github.com/collective/collective.restapi.pam
- Documentation: https://collectiverestapipam.readthedocs.io


License
-------

The project is licensed under the GPLv2.

.. _`plone.app.multilingual`: https://pypi.python.org/pypi/plone.app.multilingual
